==> haskell-cairo-0.13.4.2-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cairo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cairo
version: 0.13.4.2
id: cairo-0.13.4.2-7N5nkfqUtjLFGkblKdb417
key: cairo-0.13.4.2-7N5nkfqUtjLFGkblKdb417
license: BSD3
copyright: (c) 2001-2010 The Gtk2Hs Team, (c) Paolo Martini 2005, (c) Abraham Egnor 2003, 2004, (c) Aetion Technologies LLC 2004
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the Cairo library.
description:
    Cairo is a library to render high quality vector graphics. There
    exist various backends that allows rendering to Gtk windows, PDF,
    PS, PNG and SVG documents, amongst others.
category: Graphics
author: Axel Simon, Duncan Coutts
exposed: True
indefinite: False
exposed-modules:
    Graphics.Rendering.Cairo Graphics.Rendering.Cairo.Internal
    Graphics.Rendering.Cairo.Matrix Graphics.Rendering.Cairo.Types
hidden-modules: Graphics.Rendering.Cairo.Internal.Drawing.Cairo
                Graphics.Rendering.Cairo.Internal.Drawing.Paths
                Graphics.Rendering.Cairo.Internal.Drawing.Patterns
                Graphics.Rendering.Cairo.Internal.Drawing.Text
                Graphics.Rendering.Cairo.Internal.Drawing.Transformations
                Graphics.Rendering.Cairo.Internal.Fonts.FontOptions
                Graphics.Rendering.Cairo.Internal.Surfaces.Image
                Graphics.Rendering.Cairo.Internal.Surfaces.PNG
                Graphics.Rendering.Cairo.Internal.Surfaces.Surface
                Graphics.Rendering.Cairo.Internal.Utilities
                Graphics.Rendering.Cairo.Internal.Surfaces.PDF
                Graphics.Rendering.Cairo.Internal.Surfaces.PS
                Graphics.Rendering.Cairo.Internal.Surfaces.SVG
                Graphics.Rendering.Cairo.Internal.Region
abi: 6970289c86bb7b47beddd80b168eddfc
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cairo-0.13.4.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/cairo-0.13.4.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-cairo
hs-libraries: HScairo-0.13.4.2-7N5nkfqUtjLFGkblKdb417
extra-libraries:
    z cairo
include-dirs: /usr/include/cairo /usr/include/pixman-1
              /usr/include/uuid /usr/include/freetype2 /usr/include/harfbuzz
              /usr/include/glib-2.0 /usr/lib/glib-2.0/include
              /usr/include/libpng16
depends:
    base-4.10.1.0 utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj bytestring-0.10.8.2
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc array-0.5.2.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=e0ce70380190fd366eaf58242d407bf1
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=ada793ec1f149425d0c0689d53e1173b
             array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
haddock-interfaces: /usr/share/doc/haskell-cairo/html/cairo.haddock
haddock-html: /usr/share/doc/haskell-cairo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cairo-0.13.5.0-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cairo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cairo
version: 0.13.5.0
id: cairo-0.13.5.0-D8cAZzW763i3yjg7h3iy8R
key: cairo-0.13.5.0-D8cAZzW763i3yjg7h3iy8R
license: BSD-3-Clause
copyright: (c) 2001-2010 The Gtk2Hs Team, (c) Paolo Martini 2005, (c) Abraham Egnor 2003, 2004, (c) Aetion Technologies LLC 2004
maintainer: gtk2hs-users@lists.sourceforge.net
author: Axel Simon, Duncan Coutts
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the Cairo library.
description:
    Cairo is a library to render high quality vector graphics. There
    exist various backends that allows rendering to Gtk windows, PDF,
    PS, PNG and SVG documents, amongst others.
category: Graphics
abi: c2b9881d4d440309ad48793ba8797ee9
exposed: True
exposed-modules:
    Graphics.Rendering.Cairo Graphics.Rendering.Cairo.Internal
    Graphics.Rendering.Cairo.Matrix Graphics.Rendering.Cairo.Types
hidden-modules: Graphics.Rendering.Cairo.Internal.Drawing.Cairo
                Graphics.Rendering.Cairo.Internal.Drawing.Paths
                Graphics.Rendering.Cairo.Internal.Drawing.Patterns
                Graphics.Rendering.Cairo.Internal.Drawing.Text
                Graphics.Rendering.Cairo.Internal.Drawing.Transformations
                Graphics.Rendering.Cairo.Internal.Fonts.FontOptions
                Graphics.Rendering.Cairo.Internal.Surfaces.Image
                Graphics.Rendering.Cairo.Internal.Surfaces.PNG
                Graphics.Rendering.Cairo.Internal.Surfaces.Surface
                Graphics.Rendering.Cairo.Internal.Utilities
                Graphics.Rendering.Cairo.Internal.Surfaces.PDF
                Graphics.Rendering.Cairo.Internal.Surfaces.PS
                Graphics.Rendering.Cairo.Internal.Surfaces.SVG
                Graphics.Rendering.Cairo.Internal.Region
import-dirs: /usr/lib/ghc-8.4.2/site-local/cairo-0.13.5.0
library-dirs: /usr/lib/ghc-8.4.2/site-local/cairo-0.13.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-cairo
hs-libraries: HScairo-0.13.5.0-D8cAZzW763i3yjg7h3iy8R
extra-libraries:
    z cairo
include-dirs: /usr/include/cairo /usr/include/glib-2.0
              /usr/lib/glib-2.0/include /usr/include/pixman-1
              /usr/include/freetype2 /usr/include/libpng16 /usr/include/harfbuzz
              /usr/include/uuid
depends:
    base-4.11.1.0 utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    text-1.2.3.0 bytestring-0.10.8.2 mtl-2.2.2 array-0.5.2.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=98c3aed4d9f965690ee596928a6a8eec
             text-1.2.3.0=5654b56910ce698015ec900075c28f62
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
             mtl-2.2.2=a7bec7c72de63625528e8aa4479db2c8
             array-0.5.2.0=59560c027ff6ea5b7e467a38c579b575
haddock-interfaces: /usr/share/doc/haskell-cairo/html/cairo.haddock
haddock-html: /usr/share/doc/haskell-cairo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
